==> nextcloud-12.0.2.tgz: nextcloud/apps/activity/l10n/cs.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktivity",
    "An error occurred while loading activities" : "Při načítání aktivit došlo k chybě",
    "No activity yet" : "Zatím žádná aktivita",
    "Load more activities" : "Načíst více aktivit",
    "Copied!" : "Zkopírováno!",
    "Not supported!" : "Nepodporováno!",
    "Press ⌘-C to copy." : "Zmáčknout ⌘-C pro kopírování.",
    "Press Ctrl-C to copy." : "Zmáčknout Ctrl-C pro kopírování.",
    "{name} (invisible)" : "{name} (neviditelné)",
    "{name} (restricted)" : "{name} (omezeno)",
    "in {path}" : "v {path}",
    "This stream will show events like additions, changes & shares" : "Datový proud bude zobrazovat události jako přidání, změny a sdílení",
    "There are no events for this filter" : "Pro tato kritéria nejsou žádné události",
    "Today" : "Dnes",
    "Yesterday" : "Včera",
    "Personal activity feed for %s" : "Přehled aktivit uživatele %s",
    "Your feed URL is invalid" : "URL adresa kanálu není platná",
    "Your settings have been updated." : "Vaše nastavení bylo aktualizováno.",
    "Settings have been updated." : "Nastavení byla uložena.",
    "Mail" : "Pošta",
    "Stream" : "Proud",
    "All activities" : "Všechny aktivity",
    "By others" : "Ostatními",
    "By you" : "Vámi",
    "\"remote user\"" : "\"vzdálený uživatel\"",
    "Hello %s" : "Ahoj %s",
    "Hello %s," : "Vítejte %s,",
    "There was some activity at %s" : "Na %s došlo k něaké aktivitě",
    "_and %n more _::_and %n more _" : ["a %n další","a %n další","a %n další"],
    "Activity notification" : "Upozornění na aktivity",
    ", " : ", ",
    "%s and %s" : "%s a %s",
    "Activity" : "Aktivita",
    "Activity feed" : "Přehled aktivit",
    "Configure the default activity settings for new users." : "Nastavte výchozí nastavení aktivit pro nové uživatele.",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Zvolte, o kterých aktivitách budete upozorněn(a) e-mailem a které se zobrazí v proudu aktivit v aplikaci.",
    "List your own actions in the stream" : "Zobrazte vlastní akce v proudu",
    "Notify about your own actions via email" : "Posílat oznámení o vlastních činnostech emailem",
    "You need to set up your email address before you can receive notification emails." : "Pokud chcete dostávat upozornění emailem, musíte nejprve nastavit svou emailovou adresu.",
    "Send emails:" : "Posílat emaily:",
    "Hourly" : "Každou hodinu",
    "Daily" : "Denně",
    "Weekly" : "Týdně",
    "Settings" : "Nastavení",
    "Enable RSS feed" : "Povolit RSS kanál",
    "No more events to load" : "Žádné další události k načtení",
    "Files" : "Soubory",
    "Error loading activities" : "Chyba načtení aktivit",
    "No activities" : "Žádné aktivity",
    "You are receiving this email because the following things happened at %s" : "Dostali jste tento email, protože došlo k následujícím událostem na %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* a %n další","* a %n dalších ","* a %n dalších "]
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-13.0.1.tgz: nextcloud/apps/activity/l10n/cs.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktivity",
    "An error occurred while loading activities" : "Při načítání aktivit došlo k chybě",
    "No activity yet" : "Zatím žádná aktivita",
    "Load more activities" : "Načíst více aktivit",
    "Copied!" : "Zkopírováno!",
    "Not supported!" : "Nepodporováno!",
    "Press ⌘-C to copy." : "Pro zkopírování stiskněte ⌘-C.",
    "Press Ctrl-C to copy." : "Pro zkopírování stiskněte Ctrl-C.",
    "Home" : "Domů",
    "{name} (invisible)" : "{name} (neviditelné)",
    "{name} (restricted)" : "{name} (omezeno)",
    "in {path}" : "v {path}",
    "This stream will show events like additions, changes & shares" : "Tento stream bude zobrazovat události jako přidání, změny a sdílení",
    "There are no events for this filter" : "Pro tato kritéria nejsou žádné události",
    "Today" : "Dnes",
    "Yesterday" : "Včera",
    "Open file" : "Otevřít soubor",
    "Personal activity feed for %s" : "Přehled aktivit uživatele %s",
    "Your feed URL is invalid" : "URL adresa kanálu není platná",
    "Your settings have been updated." : "Vaše nastavení bylo aktualizováno.",
    "Settings have been updated." : "Nastavení byla uložena.",
    "All activities" : "Všechny aktivity",
    "By others" : "Ostatními",
    "By you" : "Vámi",
    "\"remote user\"" : "\"vzdálený uživatel\"",
    "Activity notification for %s" : "Oznámení aktivit pro %s",
    "Hello %s" : "Ahoj %s",
    "Hello %s," : "Vítejte %s,",
    "There was some activity at %s" : "Na %s došlo k následující aktivitě",
    "_and %n more _::_and %n more _" : ["a %n další","a %n další","a %n další"],
    ", " : ", ",
    "%s and %s" : "%s a %s",
    "Mail" : "Pošta",
    "Stream" : "Proud",
    "Activity" : "Aktivita",
    "Activity feed" : "Přehled aktivit",
    "Send activity emails" : "Posílat e-maily o aktivitě",
    "Default settings" : "Výchozí nastavení",
    "Configure the default activity settings for new users." : "Nastavte výchozí nastavení aktivit pro nové uživatele.",
    "List your own actions in the stream" : "Zobrazit vlastní akce v proudu",
    "Notify about your own actions via email" : "Posílat oznámení o vašich činnostech e-mailem",
    "You need to set up your email address before you can receive notification emails." : "Pokud chcete dostávat upozornění e-mailem, musíte nejprve nastavit svou e-mailovou adresu.",
    "Send emails:" : "Posílat e-maily:",
    "As soon as possible" : "Co nejdříve",
    "Hourly" : "Každou hodinu",
    "Daily" : "Denně",
    "Weekly" : "Týdně",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Zvolte, o kterých aktivitách budete upozorněn(a) e-mailem a které se zobrazí v proudu aktivit v aplikaci.",
    "Choose which activities you want to see in your stream." : "Zvolte, které aktivity chcete vidět ve vašem streamu.",
    "Settings" : "Nastavení",
    "Enable RSS feed" : "Povolit RSS kanál",
    "RSS feed" : "RSS kanál",
    "No more events to load" : "Žádné další události k načtení",
    "Files" : "Soubory",
    "Activity notification" : "Upozornění na aktivity"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
